
clear


* Parameters
global alow = 40
global ahigh = 43
global maxobs = $ahigh-$alow +1     // age range for lifetime income
global minobs = 3     // minimum observation requirement
global cohortlength = 9 -$minobs  // max cohort length to stay within new sample periods (2009 onward) 
global ng=5 // number of income groups


quietly {

use data_clean.dta, clear


* control inflation (2012 price)
merge m:1 year using cpi.dta
drop if _merge~=3
drop _merge

replace inc = inc*100/cpi


sort hhid year

* completed fertility 
bys hhid: egen comp_fertility = max(n_child_head)

* Setting age restriction to construct lifetime income measure
keep if age_head_f >= $alow & age_head_f <= $ahigh

* drop if hhid has two wives
by hhid: egen birth_year_f_mean = mean(birth_year_f)
by hhid: gen birth_year_f_dev = abs(birth_year_f-birth_year_f_mean)
keep if birth_year_f_dev < 2

* maximum age of wife in the data
by hhid: egen maxage = max(age_head_f)
* minimum age of wife in the data
by hhid: egen minage = min(age_head_f)

bys hhid: gen numobs = _N

//tab numobs


* keep only "married with spouse"
gen couple=1 if age_head_m~=. & age_head_f~=.
replace couple=0 if couple==.

//tab couple married_f, m   

keep if couple==1 & married_f~=4  & married_f~=5 


* including samples observed any x periods 
keep if numobs >= $minobs


bys hhid: egen lifeinc = mean(inc)


* Define cohort age band (based on 2017 being most recent year)
global cohort1max = 2017 -$alow -$minobs +1
global cohort1min = $cohort1max -$cohortlength +1
global cohort0max = 2008 -$alow -$minobs +1
global cohort0min = $cohort0max -$cohortlength +1

* generate birth cohort (automatically select)
recode birth_year_f $cohort0min/$cohort0max=0 $cohort1min/$cohort1max=1, generate(birth_cohort) 


* Remove repetition of households
by hhid: keep if _n==1
keep if birth_cohort==0 | birth_cohort==1 // cohort=0: Old cohort, cohort=1 Young cohort

gen childless = (comp_fertility==0)	

}

********************************************************************************
* Table A1
tab comp_fertility if birth_cohort==1, matcell(freq) matrow(names)   // new (modified)

putexcel set output\Tables, sheet(Table_A1, replace) modify  // new
putexcel A1=("# Children") A2=matrix(names) B1=("Percent") B2=matrix(freq/r(N)*100), nformat(0.00)  // new
********************************************************************************

********************************************************************************
* Gini income (birth_cohort==1 for the 1970-75 cohort used in the paper)
ginidesc lifeinc, by(birth_cohort) m(a1) gk(a2)

putexcel set output\Statistics, modify   // new
putexcel A1=("Statistics") B1=("Value")  // new
putexcel A2=("Gini income") B2=matrix(a2[2,2]), nformat(0.000)  // new
********************************************************************************

********************************************************************************
* Overall childlessness rate (birth_cohort==1 for the 1970-75 cohort used in the paper)
mean childless if birth_cohort==1

putexcel A3=("overall childlessness rate ('70-'75)") B3=matrix(e(b)[1,1]*100), nformat(0.0)  // new

mean childless if birth_cohort==0

putexcel A4=("overall childlessness rate ('61-'66)") B4=matrix(e(b)[1,1]*100), nformat(0.0)  // new
********************************************************************************

quietly {

* Elasticity
			 
* fertility and childlessness rate
mat result=J($ng*2,13,.)
mat colnames result = birth_year group totfert_inc_b totfert_inc_b_ub totfert_inc_b_lb ///
                      ln_totfert_inc_b cless_inc_b cless_inc_b_ub cless_inc_b_lb inc_b ///
					  ln_inc_b n_total n_single

bys hhid: gen counthh = 1 if _n==1
								 
local row=1
qui foreach b of num 0 1 {
	
	xtile inc_both = lifeinc if birth_cohort==`b', nq($ng)
	
	foreach g of num 1/$ng {	

	mat result[`row',1] = `b'
	mat result[`row',2] = `g'
		
	ci mean comp_fertility if inc_both==`g' & birth_cohort==`b'
	
	mat result[`row',3] = r(mean)
	mat result[`row',4] = r(ub)
	mat result[`row',5] = r(lb)
	mat result[`row',6] = ln(result[`row',3])
	
	ci mean childless if inc_both==`g' & birth_cohort==`b'
	
	mat result[`row',7] = r(mean)
	mat result[`row',8] = r(ub)
	mat result[`row',9] = r(lb)
	
	ci mean lifeinc if inc_both==`g' & birth_cohort==`b'
	
	mat result[`row',10] = r(mean)
	
	mat result[`row',11] = ln(result[`row',10])
	
	count if inc_both==`g' & birth_cohort==`b'
	mat result[`row',12] = r(N)
	
	count if inc_both==`g' & birth_cohort==`b' & couple~=1
	mat result[`row',13] = r(N)
	
	local row=`row'+1
}
drop inc_both
}
mat list result

drop _all
svmat result, names(col)

}

********************************************************************************
* Income elasticity of demand for children (birth_cohort==1 for the 1970-75 cohort used in the paper)
qui reg ln_totfert_inc_b ln_inc_b if birth_year==1
mat list e(b)

putexcel A5=("Income elasticity of fertility") B5=matrix(e(b)[1,1]), nformat(0.000)  // new
********************************************************************************

********************************************************************************
* Figure 1. A.
* Total margin of fertility (level)
twoway connected totfert_inc_b ln_inc_b if birth_year==1, msymbol(D) msize(1.1) lwidth(0.8) color(ebblue) ///
ytitle("Number of children", size(large)) xtitle("Log family income in 2012 KRW", size(large)) ///
ylabel(1.7 (0.1) 2.1, labsize(medlarge) nogrid) xlabel(,labsize(medlarge) nogrid) ///
plotregion(color(white)) graphregion(color(white)) scheme(cleanplots)

graph export output\Figure_1_A.pdf, replace    // new
********************************************************************************

********************************************************************************
* Figure 1. B.
* Extensive margin of fertility (level)
gen cless_inc_b_pct = cless_inc_b*100

twoway connected cless_inc_b_pct ln_inc_b if birth_year==1, msymbol(D) msize(1.1) lwidth(0.8) color(orange_red) ///
ytitle("Childlessness rate (%)", size(large)) xtitle("Log family income in 2012 KRW", size(large)) ///
ylabel(, labsize(medlarge) nogrid) xlabel(,labsize(medlarge) nogrid) ///
plotregion(color(white)) graphregion(color(white)) scheme(cleanplots)

graph export output\Figure_1_B.pdf, replace    // new
********************************************************************************

********************************************************************************
* Table A7
mat tableA7 = (result[6..10,3],result[1..5,3],result[6..10,7]*100,result[1..5,7]*100)
mat colnames tableA7 = childN_young childN_old Child0_young Child0_old
mat list tableA7

putexcel set output\Tables, sheet(Table_A7, replace) modify  // new
putexcel A1=matrix(tableA7), nformat(0.00) names  // new
********************************************************************************


********************************************************************************
********************************************************************************
* Analysis including singles for Figure A6
********************************************************************************
********************************************************************************

quietly {

use data_clean.dta, clear


* control inflation (2012 price)
merge m:1 year using cpi.dta
drop if _merge~=3
drop _merge

replace inc = inc*100/cpi


sort hhid year

* completed fertility 
bys hhid: egen comp_fertility = max(n_child_head)

* Setting age restriction to construct lifetime income measure
keep if age_head_f >= $alow & age_head_f <= $ahigh


* drop if hhid has two wives
by hhid: egen birth_year_f_mean = mean(birth_year_f)
by hhid: gen birth_year_f_dev = abs(birth_year_f-birth_year_f_mean)
keep if birth_year_f_dev < 2

* maximum age of wife in the data
by hhid: egen maxage = max(age_head_f)
* minimum age of wife in the data
by hhid: egen minage = min(age_head_f)

bys hhid: gen numobs = _N

tab numobs

* keep only "married with spouse"
gen couple=1 if age_head_m~=. & age_head_f~=.
replace couple=0 if couple==.

//tab couple married_f, m 


* including samples observed any x periods 
keep if numobs >= $minobs


bys hhid: egen lifeinc = mean(inc)

* Define cohort age band (based on 2017 being most recent year)
global cohort1max = 2017 -$alow -$minobs +1
global cohort1min = $cohort1max -$cohortlength +1
global cohort0max = 2008 -$alow -$minobs +1
global cohort0min = $cohort0max -$cohortlength +1

* generate birth cohort (automatically select)
recode birth_year_f $cohort0min/$cohort0max=0 $cohort1min/$cohort1max=1, generate(birth_cohort) 


* Remove repetition of households
by hhid: keep if _n==1
keep if birth_cohort==0 | birth_cohort==1

gen childless = (comp_fertility==0)	

* Elasticity
			 
* fertility and childlessness rate
mat result=J($ng*2,13,.)
mat colnames result = birth_year group totfert_inc_b totfert_inc_b_ub totfert_inc_b_lb ///
                      ln_totfert_inc_b cless_inc_b cless_inc_b_ub cless_inc_b_lb inc_b ///
					  ln_inc_b n_total n_single

bys hhid: gen counthh = 1 if _n==1
								 
local row=1
qui foreach b of num 0 1 {
	
	xtile inc_both = lifeinc if birth_cohort==`b', nq($ng)
	
	foreach g of num 1/$ng {	

	mat result[`row',1] = `b'
	mat result[`row',2] = `g'
		
	ci mean comp_fertility if inc_both==`g' & birth_cohort==`b'
	
	mat result[`row',3] = r(mean)
	mat result[`row',4] = r(ub)
	mat result[`row',5] = r(lb)
	mat result[`row',6] = ln(result[`row',3])
	
	ci mean childless if inc_both==`g' & birth_cohort==`b'
	
	mat result[`row',7] = r(mean)
	mat result[`row',8] = r(ub)
	mat result[`row',9] = r(lb)
	
	ci mean lifeinc if inc_both==`g' & birth_cohort==`b'
	
	mat result[`row',10] = r(mean)
	
	mat result[`row',11] = ln(result[`row',10])
	
	count if inc_both==`g' & birth_cohort==`b'
	mat result[`row',12] = r(N)
	
	count if inc_both==`g' & birth_cohort==`b' & couple~=1
	mat result[`row',13] = r(N)
	
	local row=`row'+1
}
drop inc_both
}
mat list result

drop _all
svmat result, names(col)

}

********************************************************************************
* Figure A6 - A
* Total margin of fertility (level)
twoway connected totfert_inc_b ln_inc_b if birth_year==1, msymbol(D) msize(1.1) lwidth(0.8) color(ebblue) ///
ytitle("Number of children", size(large)) xtitle("Log family income in 2012 KRW", size(large)) ///
ylabel(1.4 (0.2) 2.0, labsize(medlarge) nogrid) xlabel(,labsize(medlarge) nogrid) ///
plotregion(color(white)) graphregion(color(white)) scheme(cleanplots)

graph export output\Figure_A6_A.pdf, replace    // new
********************************************************************************

********************************************************************************
* Figure A6 - B
* Extensive margin of fertility (level)
gen cless_inc_b_pct = cless_inc_b*100

twoway connected cless_inc_b_pct ln_inc_b if birth_year==1, msymbol(D) msize(1.1) lwidth(0.8) color(orange_red) ///
ytitle("Childlessness rate (%)", size(large)) xtitle("Log family income in 2012 KRW", size(large)) ///
ylabel(0(5)20, labsize(medlarge) nogrid) xlabel(,labsize(medlarge) nogrid) ///
plotregion(color(white)) graphregion(color(white)) scheme(cleanplots)

graph export output\Figure_A6_B.pdf, replace    // new
********************************************************************************
