

clear


* Parameters
global alow = 40
global ahigh = 43
global maxobs = $ahigh-$alow +1     // age range for lifetime income
global minobs = 3     // minimum observation requirement
global cohortlength = 9 -$minobs  // max cohort length to stay within new sample periods (2009 onward) 
global ng=5 // number of income groups


*****************************
* Income and education costs 
*****************************

use data_clean.dta, clear

* control inflation (2012 price)
merge m:1 year using cpi.dta
drop if _merge~=3
drop _merge

* income
replace inc = inc*100/cpi

* education costs
replace expenditure_month = expenditure_month*100/cpi
replace educost_pub_month = educost_pub_month*100/cpi
replace educost_priv_month = educost_priv_month*100/cpi


* Define cohort age band (based on 2017 being most recent year)
global cohort1max = 2017 -$alow -$minobs +1
global cohort1min = $cohort1max -$cohortlength +1
global cohort0max = 2008 -$alow -$minobs +1
global cohort0min = $cohort0max -$cohortlength +1

* generate birth cohort (automatically select)
recode birth_year_f $cohort0min/$cohort0max=0 $cohort1min/$cohort1max=1, generate(birth_cohort) 


keep if birth_cohort==0 | birth_cohort==1

* income quintile by year
gen inc_both=.
gen inc_both0=.
gen inc_both1=.

qui foreach y of num 4/20 {
	xtile temp = inc if year==`y', nq($ng)
	replace inc_both = temp if year==`y'
	drop temp
}
qui foreach y of num 4/20 {
	foreach b of num 0 1 {
	xtile temp = inc if year==`y' & birth_cohort==`b', nq($ng)
	replace inc_both`b' = temp if year==`y' & birth_cohort==`b'
	drop temp
}
}

* drop data based on children's age
drop if max_age_child>24 & max_age_child~=.
drop if n_child_head==0


* education costs per child 
gen educost_priv_cap = educost_priv_month/n_child_head
replace educost_priv_cap=0 if n_child_head==0

gen educost_pub_cap = educost_pub_month/n_child_head
replace educost_pub_cap=0 if n_child_head==0

gen educost_tot_cap = educost_priv_cap + educost_pub_cap


**************************************************
* education costs and income over life of children
**************************************************

* only households with one child

mat result=J(25,5,.)
mat colnames result = age educost_age income_age share_age nhh_age

local row=1
qui foreach a of num 0/24 {	

	mat result[`row',1] = `a'
		
	ci mean educost_tot_cap if n_child_head==1 & max_age_child==`a' & birth_cohort==1
	mat result[`row',2] = r(mean)
	
	ci mean inc if n_child_head==1 & max_age_child==`a' & educost_tot_cap~=. & birth_cohort==1
	mat result[`row',3] = r(mean)/12
	
	mat result[`row',4] = result[`row',2]/result[`row',3]*100
	
	count if n_child_head==1 & max_age_child==`a' & educost_tot_cap~=. & birth_cohort==1
	mat result[`row',5] = r(N)
	
	local row=`row'+1
}
mat list result
svmat result, names(col)

********************************************************************************
* Fraction of total life-time education spending per child in income
egen temp1 = total(educost_age)
egen temp2 = total(income_age)
gen temp3 = temp1/temp2*100
mean temp3   // new(modified)
drop temp*

putexcel set output\Statistics, modify   // new
putexcel A6=("Fraction of education spending per child in income") B6=matrix(e(b)[1,1]), nformat(0.0)  // new
********************************************************************************


********************************************************************************
* Figure A2
twoway connected educost_age age, yaxis(1) ytitle("10,000 KRW (2012)", size(large)) msize(1.1) msymbol(O) lwidth(0.8) color(ebblue) || ///
connected share_age age, yaxis(2) ytitle("Percent", axis(2) size(large)) msize(1.1) msymbol(D) lpattern(--) lwidth(0.8) color(orange) xline(7 13 16 19, lcolor(gs10)) ///
legend(cols(1) order(1 2) position(5) ring(0) bmargin(large) size(medlarge) label(1 "Monthly expenditure") label(2 "Share relative to income")) ///
xtitle("Child age", size(large)) ///
ylabel(, labsize(medlarge) nogrid) ylabel(, axis(2) labsize(medlarge) nogrid) xlabel(,labsize(medlarge) nogrid) ///
plotregion(color(white)) graphregion(color(white)) scheme(cleanplots)

graph export output\Figure_A2.pdf, replace    // new
********************************************************************************


*********************************************
* merge education cost data for each children
*********************************************

merge 1:1 hhid year using data_educost_detail_wide.dta
drop if _merge==2
drop _merge

forval x=1/5 {
replace edu_totcost`x' = edu_totcost`x'*100/cpi
}

* remove if a child's age is greater than 24
forval x=1/5 {
replace edu_totcost`x' = . if chage`x'>24
replace chage`x' = . if chage`x'>24
}


***************************************************
* children's ages (pre=1,elem=2,middle=3,high=4)
***************************************************

forval sib=1/5 {
recode chage`sib' 0/6=1 7/12=2 13/15=3 16/18=4, generate(school`sib')
}

* costs for children before going to a college
qui forval sch=1/4 {
forval sib=1/5 {
gen temp`sib' = edu_totcost`sib' if school`sib'==`sch'
gen ind`sib' = (school`sib'==`sch')
}
egen cost_sch`sch' = rowtotal(temp*), missing
egen n_sch`sch' = rowtotal(ind*), missing
replace cost_sch`sch' = cost_sch`sch'/n_sch`sch'
drop temp*
drop ind*
}


foreach sch of num 1/4 {  // children's age (pre=1,elem=2,middle=3,high=4)

mat result`sch'=J(5,12,.)
mat colnames result`sch' = cost_inc_age`sch' ln_cost_inc_age`sch' inc_inc_age`sch' ln_inc_inc_age`sch' share_inc_age`sch' ///
                           nhh_inc_age`sch' birth_year`sch' group`sch' cndtl_cost`sch' zero_share`sch' expdt`sch' share_expdt`sch' 

local row=1
qui foreach b in 1 {
	foreach g of num 1/5 {	
	
	ci mean cost_sch`sch' if inc_both`b'==`g' & birth_cohort==`b'
	mat result`sch'[`row',1] = r(mean)
	
	mat result`sch'[`row',2] = ln(result`sch'[`row',1])
	
	ci mean inc if inc_both`b'==`g' & birth_cohort==`b' & cost_sch`sch'~=.
	mat result`sch'[`row',3] = r(mean)
	mat result`sch'[`row',4] = ln(r(mean))
	mat result`sch'[`row',5] = result`sch'[`row',1]/(r(mean)/12)*100
	
	count if inc_both`b'==`g' & birth_cohort==`b' & cost_sch`sch'~=.
	mat result`sch'[`row',6] = r(N)
	
	mat result`sch'[`row',7] = `b'
	mat result`sch'[`row',8] = `g'
	
	ci mean cost_sch`sch' if inc_both`b'==`g' & birth_cohort==`b' & (cost_sch`sch'>0 & cost_sch`sch'~=.)
	mat result`sch'[`row',9] = r(mean)
		
	count if inc_both`b'==`g' & birth_cohort==`b' & cost_sch`sch'==0
	mat result`sch'[`row',10] = r(N)/result`sch'[`row',6]
	
	ci mean expenditure_month if inc_both`b'==`g' & birth_cohort==`b' & cost_sch`sch'~=.	
	mat result`sch'[`row',11] = r(mean)
	mat result`sch'[`row',12] = result`sch'[`row',1]/r(mean)*100
	
	local row=`row'+1
}
}
mat list result`sch'
svmat result`sch', names(col)
}

********************************************************************************
* Income elasticity of private education expenditures
reg ln_cost_inc_age1 ln_inc_inc_age1 if birth_year1==1
putexcel A7=("Income elasticity of private education (pre)") B7=matrix(e(b)[1,1]), nformat(0.00)  // new

reg ln_cost_inc_age2 ln_inc_inc_age2 if birth_year2==1
putexcel A8=("Income elasticity of private education (elem)") B8=matrix(e(b)[1,1]), nformat(0.00)  // new

reg ln_cost_inc_age3 ln_inc_inc_age3 if birth_year3==1
putexcel A9=("Income elasticity of private education (middle)") B9=matrix(e(b)[1,1]), nformat(0.00)  // new

reg ln_cost_inc_age4 ln_inc_inc_age4 if birth_year4==1
putexcel A10=("Income elasticity of private education (high)") B10=matrix(e(b)[1,1]), nformat(0.00)  // new
********************************************************************************

* weighted average across all ages
mat result = (result1*7+result2*6+result3*3+result4*3)/19
mat colnames result = cost_inc_age ln_cost_inc_age inc_inc_age ln_inc_inc_age share_inc_age ///
                      nhh_inc_age birth_year group cndtl_cost zero_share expdt share_expdt
forval r=1/5 {
mat result[`r',2] = ln(result[`r',1])
mat result[`r',4] = ln(result[`r',3])
mat result[`r',5] = result[`r',1]/(result[`r',3]/12)*100
}
mat list result
svmat result, names(col)

********************************************************************************
* Income elasticity of investment
reg ln_cost_inc_age ln_inc_inc_age if birth_year==1

putexcel A11=("Income elasticity of investment") B11=matrix(e(b)[1,1]), nformat(0.000)  // new
********************************************************************************

********************************************************************************
* Figure A1
twoway connected ln_cost_inc_age1 ln_inc_inc_age1 if birth_year1==1, msize(1.3) msymbol(O) lwidth(0.6) lpattern(shortdash) color(ebblue*0.8) || ///
connected ln_cost_inc_age2 ln_inc_inc_age2 if birth_year2==1, msize(1.3) msymbol(D) lwidth(0.6) lpattern(shortdash_dot) color(midgreen*0.8) || ///
connected ln_cost_inc_age3 ln_inc_inc_age3 if birth_year3==1, msize(1.3) msymbol(T) lwidth(0.6) lpattern(dash) color(orange*0.8) || ///
connected ln_cost_inc_age4 ln_inc_inc_age4 if birth_year4==1, msize(1.3) msymbol(S) lwidth(0.6) lpattern(longdash_dot) color(cranberry*0.8)  ///
ytitle("Log education spending (2012 KRW)", size(large)) xtitle("Log family income (2012 KRW)", size(large)) ///
ylabel(2(0.5)4, labsize(medlarge) nogrid) xlabel(,labsize(medlarge) nogrid) ///
legend(cols(1) order(1 2 3 4) position(5) ring(0) bmargin(small) size(medlarge) label(1 "Pre-School") label(2 "Elementary") label(3 "Middle") label(4 "High")) ///
plotregion(color(white)) graphregion(color(white)) scheme(cleanplots) 

graph export output\Figure_A1.pdf, replace    // new
********************************************************************************

********************************************************************************
* Table 2
mat table2 = (result1[1..5,5],result2[1..5,5],result3[1..5,5],result4[1..5,5],result[1..5,5])
mat colnames table2 = pre elem middle high average
mat list table2

putexcel set output\Tables, sheet(Table_2, replace) modify  // new
putexcel A1=matrix(table2), nformat(0.0) names  // new
********************************************************************************

********************************************************************************
* Table A2
mat tableA2 = (result1[1..5,9],result2[1..5,9],result3[1..5,9],result4[1..5,9],result[1..5,9])
mat colnames tableA2 = pre elem middle high average
mat list tableA2

putexcel set output\Tables, sheet(Table_A2, replace) modify  // new
putexcel A1=matrix(tableA2), nformat(0.0) names  // new
********************************************************************************

********************************************************************************
* Table A3
mat tableA3 = 100*(result1[1..5,10],result2[1..5,10],result3[1..5,10],result4[1..5,10],result[1..5,10])
mat colnames tableA3 = pre elem middle high average
mat list tableA3

putexcel set output\Tables, sheet(Table_A3, replace) modify  // new
putexcel A1=matrix(tableA3), nformat(0.0) names  // new
********************************************************************************

